@@ -9,7 +9,7 @@ HistoryInfoWindow::HistoryInfoWindow(QWidget *parent) :
     QWidget *widget = new QWidget();
     QVBoxLayout *vLayout = new QVBoxLayout();
 
-    for(int i = 0; i < 9; i++)
+    for(int i = 1; i < 10 ; i++)
     {
         set.setNum(i);
         lblSet[i] = new QLabel("Set " + set + ": No info.");
@@ -29,7 +29,7 @@ void HistoryInfoWindow::load(QString name, QString group, QString date)
     int j = 0;
     QString set;
 
-    setWindowTitle(name + "/" + group);
+    setWindowTitle(name);
 
     list = xml->getHistoryByExercise(name, date);
 
