@@ -57,7 +57,7 @@ void NewProgramWindow::load(QString name, QList <QString> exercises)
 {
     QList <QString> list;
     QModelIndex index;
-
+    qDebug() << "NewProgramWindow::load name:" << name;
     oldName = name;
     list = xml->openAll();
     qDebug() << "NewProgramWindow::load 1";
@@ -80,10 +80,16 @@ void NewProgramWindow::load(QString name, QList <QString> exercises)
     txtName->setEnabled(false);
     qDebug() << "NewProgramWindow::load 4";
 
-    while(!exercises.isEmpty())
+    for(int i = 0; i < exercises.count(); i++)
     {
-        index = model->index(exercises.takeFirst().toInt(),0);
-        lstExercises->selectionModel()->select(index, QItemSelectionModel::Select);
+        for(int j = 0; j < exercises.count(); j++)
+        {
+            if(lstExercises->model()->index(j,0).data().toString() == exercises.at(i))
+            {
+                index = model->index(j,0);
+                lstExercises->selectionModel()->select(index, QItemSelectionModel::Select);
+            }
+        }
     }
 }
 
