@@ -115,7 +115,7 @@ void WeightDialog::loadCardio(QString name, QString m, QString s)
     exName = name;
     min = m;
     sec = s;
-    set = 1;
+    set = "1";
 
     modelVar = new QStandardItemModel(this);
     for (double i = 1; i < 500; i++)
@@ -180,7 +180,7 @@ void WeightDialog::save()
         reps = btnReps->valueText();
     }
     qDebug () << "WeightDialog::save 5";
-    if(set.toInt() == 1)
+    if(set.toInt() == 1)// || group == "Cardio")
     {
         xml->saveFirstSet(group, exName, weight, reps, status);
         qDebug () << "WeightDialog::save 6";
